<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Services\APIClub;
use Illuminate\Http\Request;

class VerificationController extends Controller
{
    public function verifyRC(Request $request) {
        // Validate the input first
        $request->validate([
            'vehicleId' => ['required', 'string', 'max:11']
        ]);

        // Send request to API
        $apiResponse = APIClub::sendRequest(APIClub::RC,
            ['vehicleId' => $request->input('vehicleId')]);

        // Handle the response or error
        if ($apiResponse) {
            return response()->json($apiResponse);
        }

        return $this->handleApiError();
    }

    private function handleApiError($message = 'Failed to fetch data from the API.') {
        return response()->json([
            'success' => false,
            'error' => $message
        ], 500); // Send HTTP 500 status code for errors
    }

    public function sendAadharOTP(Request $request) {
        $request->validate([
            'aadhaar_no' => ['required', 'string', 'size:12'] // Aadhaar should be exactly 12 digits
        ]);

        // Send POST request to the API to send OTP
        $apiResponse = APIClub::sendRequest(APIClub::SEND_OTP, [
            'aadhaar_no' => $request->input("aadhaar_no"),
        ]);

        // Handle the response or error
        if ($apiResponse) {
            return response()->json($apiResponse);
        }

        return $this->handleApiError('Failed to send OTP. Please try again.');

    }

    public function verifyAadharOTP(Request $request) {
        // Validate the OTP input
        $request->validate([
            'ref_id' => ["required", "string"],
            'otp' => ['required', 'size:6'],
        ]);

        // Send OTP verification request
        $apiResponse = APIClub::sendRequest(APIClub::SUBMIT_OTP, [
            'ref_id' => $request->input("ref_id"),
            'otp' => $request->input('otp'),
        ]);

        // Handle the response or error
        if ($apiResponse) {
            return response()->json($apiResponse);
        }

        return $this->handleApiError('Failed to verify OTP. Please try again.');
    }

    public function verifyDL(Request $request) {
        // Validate the input Driving License number
        $request->validate([
            'dl_no' => ['required', 'string', 'min:10'],
            'dob' => ['required'],
        ]);

        // Send request to API
        $apiResponse = APIClub::sendRequest(APIClub::DL, [
            'dl_no' => $request->input('dl_no'),
            'dob' => $request->input("dob")
        ]);

        // Handle the response or error
        if ($apiResponse) {
            return response()->json($apiResponse);
        }

        return $this->handleApiError('Failed to verify DL. Please try again.');
    }
}
