<?php

namespace App\Http\Controllers;

use App\Http\Requests\DriverRequest;
use App\Http\Resources\DriverResource;
use App\Models\Driver;
use Illuminate\Http\JsonResponse;

class DriverController extends Controller
{
    protected array $relations = [
        "transporter", "trips"
    ];

    /**
     * Display a listing of the drivers.
     */
    public function index(): JsonResponse {
        $drivers = $this->paginateOrGet(
            Driver::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            DriverResource::collection($drivers)
        );
    }

    /**
     * Store a newly created driver in storage.
     */
    public function store(DriverRequest $request): JsonResponse {
        $driver = Driver::create($request->validated());

        return $this->respondCreated(
            new DriverResource($driver),
            "Driver created successfully!"
        );
    }

    /**
     * Display the specified driver.
     */
    public function show(Driver $driver): JsonResponse {
        $driver->loadMissing($this->getRelations());

        return $this->respondWithResource(new DriverResource($driver));
    }

    /**
     * Update the specified driver in storage.
     */
    public function update(DriverRequest $request, Driver $driver): JsonResponse {
        $driver->update($request->validated());

        return $this->respondUpdated(
            new DriverResource($driver),
            "Driver updated successfully!"
        );
    }

    /**
     * Remove the specified driver from storage.
     */
    public function destroy(Driver $driver): JsonResponse {
        $driver->delete();

        return $this->respondSuccess("Driver deleted successfully!");
    }
}
