<?php

namespace App\Http\Controllers;

use App\Http\Requests\EPodRequest;
use App\Http\Resources\EpodResource;
use App\Models\EPod;
use Illuminate\Http\JsonResponse;

class EPodController extends Controller
{
    protected array $relations = [
        "trip", "receiver"
    ];

    protected ?string $resourceName = "e-pods";

    protected array $fileFieldNames = [
        "photo_1", "photo_2", "photo_3", "photo_4", "video"
    ];

    protected array $fileFolderPaths = [
        "photos", "photos", "photos", "photos", "videos"
    ];

    /**
     * Display a listing of the ePods.
     */
    public function index(): JsonResponse {
        $ePods = $this->paginateOrGet(
            EPod::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            EPodResource::collection($ePods)
        );
    }

    /**
     * Store a newly created ePod in storage.
     */
    public function store(EPodRequest $request): JsonResponse {
        $ePod = EPod::create($request->validated());

        return $this->respondCreated(
            new EPodResource($ePod),
            "EPod created successfully!"
        );
    }

    /**
     * Display the specified ePod.
     */
    public function show(EPod $ePod): JsonResponse {
        $ePod->loadMissing($this->getRelations());

        return $this->respondWithResource(new EPodResource($ePod));
    }

    /**
     * Update the specified ePod in storage.
     */
    public function update(EPodRequest $request, EPod $ePod): JsonResponse {
        $ePod->update($request->validated());

        return $this->respondUpdated(
            new EPodResource($ePod),
            "EPod updated successfully!"
        );
    }

    /**
     * Remove the specified ePod from storage.
     */
    public function destroy(EPod $ePod): JsonResponse {
        $ePod->delete();

        return $this->respondSuccess("EPod deleted successfully!");
    }
}
