<?php

namespace App\Http\Controllers;

use App\Http\Requests\TransporterRequest;
use App\Http\Resources\TransporterResource;
use App\Models\Transporter;
use Illuminate\Http\JsonResponse;

class TransporterController extends Controller
{
    protected array $relations = [
        "createdBy", "customer", "vehicles", "drivers", "trips"
    ];

    /**
     * Display a listing of the transporters.
     */
    public function index(): JsonResponse {
        $transporters = $this->paginateOrGet(
            Transporter::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            TransporterResource::collection($transporters)
        );
    }

    /**
     * Store a newly created transporter in storage.
     */
    public function store(TransporterRequest $request): JsonResponse {
        $transporter = Transporter::create($request->validated());

        return $this->respondCreated(
            new TransporterResource($transporter),
            "Transporter created successfully!"
        );
    }

    /**
     * Display the specified transporter.
     */
    public function show(Transporter $transporter): JsonResponse {
        $transporter->loadMissing($this->getRelations());

        return $this->respondWithResource(new TransporterResource($transporter));
    }

    /**
     * Update the specified transporter in storage.
     */
    public function update(TransporterRequest $request, Transporter $transporter): JsonResponse {
        $transporter->update($request->validated());

        return $this->respondUpdated(
            new TransporterResource($transporter),
            "Transporter updated successfully!"
        );
    }

    /**
     * Remove the specified transporter from storage.
     */
    public function destroy(Transporter $transporter): JsonResponse {
        $transporter->delete();

        return $this->respondSuccess("Transporter deleted successfully!");
    }
}
