<?php

namespace App\Http\Controllers;

use App\Http\Requests\VehicleRequest;
use App\Http\Resources\VehicleResource;
use App\Models\Vehicle;
use Illuminate\Http\JsonResponse;

class VehicleController extends Controller
{
    protected array $relations = [
        "transporter", "trips"
    ];

    /**
     * Display a listing of the vehicles.
     */
    public function index(): JsonResponse {
        $vehicles = $this->paginateOrGet(
            Vehicle::with($this->getRelations())->filter()->latest());

        return $this->respondWithResourceCollection(
            VehicleResource::collection($vehicles)
        );
    }

    /**
     * Store a newly created vehicle in storage.
     */
    public function store(VehicleRequest $request): JsonResponse {
        $vehicle = Vehicle::create($request->validated());

        return $this->respondCreated(
            new VehicleResource($vehicle),
            "Vehicle created successfully!"
        );
    }

    /**
     * Display the specified vehicle.
     */
    public function show(Vehicle $vehicle): JsonResponse {
        $vehicle->loadMissing($this->getRelations());

        return $this->respondWithResource(new VehicleResource($vehicle));
    }

    /**
     * Update the specified vehicle in storage.
     */
    public function update(VehicleRequest $request, Vehicle $vehicle): JsonResponse {
        $vehicle->update($request->validated());

        return $this->respondUpdated(
            new VehicleResource($vehicle),
            "Vehicle updated successfully!"
        );
    }

    /**
     * Remove the specified vehicle from storage.
     */
    public function destroy(Vehicle $vehicle): JsonResponse {
        $vehicle->delete();

        return $this->respondSuccess("Vehicle deleted successfully!");
    }
}
