<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class CustomerRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'admin_id' => ['required', 'exists:users,id'],

            'vertical_name' => ['required', 'string', 'max:254'],
            'insured_name' => ['required', 'string', 'max:254'],
            'insured_policy_no' => ['required', 'string', 'max:254'],
            'insured_contact_person_name' => ['required', 'string', 'max:254'],
            'insured_contact_person_mobile_no' => ['required'],

            'rm_name' => ['required', 'string', 'max:254'],
            'rm_mobile_no' => ['required', 'string', 'max:20'],
            'rm_email' => [
                'required', 'email', 'max:254',
                Rule::unique("customers", "rm_email")
            ],

            'under_writer_name' => ['required', 'string', 'max:254'],
            'under_writer_mobile_no' => ['required', 'string', 'max:20'],
            'under_writer_email' => [
                'required', 'email', 'max:254',
                Rule::unique("customers", "under_writer_email")
            ],

            'vertical_head_name' => ['required', 'string', 'max:254'],
            'vertical_head_mobile_no' => ['required', 'string', 'max:20'],
            'vertical_head_email' => [
                'required', 'email', 'max:254',
                Rule::unique("customers", "vertical_head_email")
            ],
        ];

        if ($this->routeIs("customers.update")) {
            $customerId = $this->route("customer");

            $rules['admin_id'][0] = "sometimes";

            $rules['vertical_name'][0] = "sometimes";
            $rules['insured_name'][0] = "sometimes";
            $rules['insured_policy_no'][0] = "sometimes";
            $rules['insured_contact_person_name'][0] = "sometimes";
            $rules['insured_contact_person_mobile_no'][0] = "sometimes";

            $rules['rm_name'][0] = "sometimes";
            $rules['rm_mobile_no'][0] = "sometimes";
            $rules['rm_email'][0] = "sometimes";
            $rules['rm_email'][3] = Rule::unique("customers", "rm_email")->ignore($customerId);

            $rules['under_writer_name'][0] = "sometimes";
            $rules['under_writer_mobile_no'][0] = "sometimes";
            $rules['under_writer_email'][0] = "sometimes";
            $rules['under_writer_email'][3] = Rule::unique("customers", "under_writer_email")->ignore($customerId);

            $rules['vertical_head_name'][0] = "sometimes";
            $rules['vertical_head_mobile_no'][0] = "sometimes";
            $rules['vertical_head_email'][0] = "sometimes";
            $rules['vertical_head_email'][3] = Rule::unique("customers", "vertical_head_email")->ignore($customerId);
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
