<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class DriverRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'transporter_id' => ['required', 'exists:transporters,id'],

            // driving license related fields
            'dl_no' => ['required', 'string', 'max:20'],
            'mobile_no' => ['required', "string", "max:20"],
            'name_as_per_aadhaar' => ['nullable', 'string'],
            'name_as_per_dl' => ['nullable', 'string'],
            'dl_dob' => ['nullable', 'date'],
            'dl_state' => ['nullable', "string", "max:50"],
            'dl_address' => ['nullable', 'string'],
            'valid_upto' => ['nullable', 'date'],
            'rto' => ['nullable', 'string'],
            'rto_code' => ['nullable', "string", "max:10"],
            'vehicle_class' => ['nullable'],

            // aadhar related fields
            'aadhaar_no' => ['required', 'string', 'max:15'],
            'aadhaar_dob' => ['nullable', 'date'],
            'country' => ['nullable', 'string', 'max:60'],
            'dist' => ['nullable', 'string', 'max:50'],
            'house' => ['nullable', 'string'],
            'landmark' => ['nullable', 'string'],
            'loc' => ['nullable', 'string'],
            'po' => ['nullable', 'string', 'max:50'],
            'aadhaar_state' => ['nullable', 'string', 'max:50'],
            'street' => ['nullable', 'string'],
            'subdist' => ['nullable', 'string', 'max:50'],
            'vtc' => ['nullable', 'string'],
        ];

        if ($this->routeIs("drivers.update") || $this->isMethod("PATCH") || $this->isMethod("PUT")) {
            $rules["transporter_id"][0] = "sometimes";
            $rules["dl_no"][0] = "sometimes";
            $rules["mobile_no"][0] = "sometimes";
            $rules["aadhaar_no"][0] = "sometimes";
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
