<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class EPodRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'trip_id' => ['required', 'exists:trips,id'],
            'receiver_id' => ['required', 'exists:users,id'],

            'latitude' => ['required', 'numeric'],
            'longitude' => ['required', 'numeric'],
            'are_goods_damaged' => ['required', 'boolean'],
            'damage_type' => ['nullable', 'required_if_accepted:are_goods_damaged', 'string', 'max:254'],
            'num_damaged_pieces' => ['nullable', 'required_if_accepted:are_goods_damaged', 'integer'],
            'delivery_date' => ['required', 'date'],
            'special_remark' => ['nullable', 'string'],
            'feedback' => ['required', 'integer', 'digits_between:0,5'],

            'photo_1' => $this->validateFile('photo_1'),
            'photo_2' => $this->validateFile('photo_2'),
            'photo_3' => $this->validateFile('photo_3'),
            'photo_4' => $this->validateFile('photo_4'),
            'video' => $this->validateFile("video"),
        ];

        if ($this->routeIs("e-pods.update")) {
            $rules["trip_id"][0] = "sometimes";
            $rules["receiver_id"][0] = "sometimes";

            $rules["latitude"][0] = "sometimes";
            $rules["longitude"][0] = "sometimes";
            $rules["are_goods_damaged"][0] = "sometimes";
            $rules["damage_type"][1] = "sometimes";
            $rules["num_damaged_pieces"][1] = "sometimes";
            $rules["delivery_date"][0] = "sometimes";
            $rules["feedback"][0] = "sometimes";
        }

        return $rules;
    }

    private function validateFile(string $field): array {
        return $this->hasFile($field)
            ? ['file', 'mimes:jpg,jpeg,png,pdf', 'max:2048']
            : ['nullable', 'string', 'max:100'];
    }

    public function authorize(): bool {
        return true;
    }
}
