<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class TransporterRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'created_by_id' => ['required', 'exists:users,id'],
            'customer_id' => ['required', 'exists:customers,id'],

            'name' => ['required', 'string', 'max:254'],
            'email' => ['required', 'email', 'max:254', Rule::unique("transporters")],
            'mobile_no_1' => ['required', "string", "max:20"],
            'mobile_no_2' => ['nullable', "string", "max:20"],
            'address' => ['required', 'string', 'max:254'],
            'state' => ['required', "string", "max:50"],
        ];

        if ($this->routeIs("transporters.update")) {
            $transporterId = $this->route("transporter");

            $rules["created_by_id"][0] = "sometimes";
            $rules["customer_id"][0] = "sometimes";
            $rules["name"][0] = "sometimes";
            $rules["email"][0] = "sometimes";
            $rules["email"][3] = Rule::unique("transporters")->ignore($transporterId);
            $rules["mobile_no_1"][0] = "sometimes";
            $rules["address"][0] = "sometimes";
            $rules["state"][0] = "sometimes";
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
