<?php

namespace App\Http\Requests;

use App\Enums\TripStatus;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class TripRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'transporter_id' => ['required', 'exists:transporters,id'],
            'dispatcher_id' => ['required', 'exists:users,id'],
            'receiver_id' => ['required', 'exists:users,id'],

            'is_chassis_no_verified' => ['required', 'boolean'],
            'is_engine_no_verified' => ['required', 'boolean'],
            'is_make_verified' => ['required', 'boolean'],
            'is_model_verified' => ['required', 'boolean'],
            'is_carrying_capacity_verified' => ['required', 'boolean'],
            'is_vehicle_type_verified' => ['required', 'boolean'],
            'is_aadhaar_verified' => ['required', 'boolean'],
            'is_dl_verified' => ['required', 'boolean'],
            'is_dob_verified' => ['required', 'boolean'],
            'is_address_verified' => ['required', 'boolean'],
            'is_mobile_no_verified' => ['required', 'boolean'],
            'dob_remark' => ['nullable', 'string', 'max:254'],
            'address_remark' => ['nullable', 'string', 'max:254'],
            'consignor_name' => ['required', 'string', 'max:254'],
            'consignee_name' => ['required', 'string', 'max:254'],
            'fast_tag_id' => ['nullable', 'string', 'max:30'],
            'dispatch_location' => ['required', 'string', 'max:254'],
            'dispatch_pincode' => ['required', 'string', 'max:10'],
            'destination_location' => ['required', 'string', 'max:254'],
            'destination_pincode' => ['required', 'string', 'max:10'],
            'latitude' => ['required', 'numeric'],
            'longitude' => ['required', 'numeric'],
            'goods_description' => ['nullable', 'string'],
            'eta' => ['required', 'date'],
            'distance' => ['required', 'numeric'],
            'is_e_pod_created' => ['sometimes', 'boolean'],
            'status' => ['required', Rule::enum(TripStatus::class)],
        ];

        if ($this->routeIs("trips.update")) {
            $rules["transporter_id"][0] = "sometimes";
            $rules["dispatcher_id"][0] = "sometimes";
            $rules["vehicle_id"][0] = "sometimes";
            $rules["driver_id"][0] = "sometimes";
            $rules["receiver_id"][0] = "sometimes";

            $rules["is_chassis_no_verified"][0] = "sometimes";
            $rules["is_engine_no_verified"][0] = "sometimes";
            $rules["is_make_verified"][0] = "sometimes";
            $rules["is_model_verified"][0] = "sometimes";
            $rules["is_carrying_capacity_verified"][0] = "sometimes";
            $rules["is_vehicle_type_verified"][0] = "sometimes";
            $rules["is_aadhaar_verified"][0] = "sometimes";
            $rules["is_dl_verified"][0] = "sometimes";
            $rules["is_dob_verified"][0] = "sometimes";
            $rules["is_address_verified"][0] = "sometimes";
            $rules["is_mobile_no_verified"][0] = "sometimes";

            $rules["consignor_name"][0] = "sometimes";
            $rules["consignee_name"][0] = "sometimes";
            $rules["dispatch_location"][0] = "sometimes";
            $rules["dispatch_pincode"][0] = "sometimes";
            $rules["destination_location"][0] = "sometimes";
            $rules["destination_pincode"][0] = "sometimes";
            $rules["latitude"][0] = "sometimes";
            $rules["longitude"][0] = "sometimes";
            $rules["eta"][0] = "sometimes";
            $rules["distance"][0] = "sometimes";
            $rules["status"][0] = "sometimes";
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
