<?php

namespace App\Http\Resources;

use App\Models\Transporter;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

/** @mixin Transporter */
class TransporterResource extends JsonResource
{
    public function toArray(Request $request): array {
        return [
            'id' => $this->id,

            'created_by_id' => $this->created_by_id,
            'customer_id' => $this->customer_id,

            'transporter_code' => $this->transporter_code,
            'name' => $this->name,
            'email' => $this->email,
            'mobile_no_1' => $this->mobile_no_1,
            'mobile_no_2' => $this->mobile_no_2,
            'address' => $this->address,
            'state' => $this->state,

            // relations
            'created_by' => new UserResource($this->whenLoaded('createdBy')),
            'customer' => new CustomerResource($this->whenLoaded('customer')),
            'vehicles' => VehicleResource::collection($this->whenLoaded("vehicles")),
            'drivers' => DriverResource::collection($this->whenLoaded("drivers")),
            'trips' => TripResource::collection($this->whenLoaded("trips")),

            // timestamps
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ];
    }
}
