<?php

namespace App\Http\Resources;

use App\Models\Trip;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

/** @mixin Trip */
class TripResource extends JsonResource
{
    public function toArray(Request $request): array {
        return [
            'id' => $this->id,

            'transporter_id' => $this->transporter_id,
            'dispatcher_id' => $this->dispatcher_id,
            'vehicle_id' => $this->vehicle_id,
            'driver_id' => $this->driver_id,
            'receiver_id' => $this->receiver_id,

            'is_chassis_no_verified' => $this->is_chassis_no_verified,
            'is_engine_no_verified' => $this->is_engine_no_verified,
            'is_make_verified' => $this->is_make_verified,
            'is_model_verified' => $this->is_model_verified,
            'is_carrying_capacity_verified' => $this->is_carrying_capacity_verified,
            'is_vehicle_type_verified' => $this->is_vehicle_type_verified,
            'is_aadhaar_verified' => $this->is_aadhaar_verified,
            'is_dl_verified' => $this->is_dl_verified,
            'is_dob_verified' => $this->is_dob_verified,
            'is_address_verified' => $this->is_address_verified,
            'is_mobile_no_verified' => $this->is_mobile_no_verified,
            'dob_remark' => $this->dob_remark,
            'address_remark' => $this->address_remark,
            'trip_code' => $this->trip_code,
            'consignor_name' => $this->consignor_name,
            'consignee_name' => $this->consignee_name,
            'fast_tag_id' => $this->fast_tag_id,
            'dispatch_location' => $this->dispatch_location,
            'dispatch_pincode' => $this->dispatch_pincode,
            'destination_location' => $this->destination_location,
            'destination_pincode' => $this->destination_pincode,
            'latitude' => $this->latitude,
            'longitude' => $this->longitude,
            'goods_description' => $this->goods_description,
            'eta' => $this->eta,
            'distance' => $this->distance,
            'is_e_pod_created' => $this->is_e_pod_created,
            'status' => $this->status,

            // relations
            'transporter' => new TransporterResource($this->whenLoaded('transporter')),
            'dispatcher' => new UserResource($this->whenLoaded('dispatcher')),
            'vehicle' => new VehicleResource($this->whenLoaded('vehicle')),
            'driver' => new DriverResource($this->whenLoaded('driver')),
            'receiver' => new UserResource($this->whenLoaded('receiver')),
            'e_pod' => new EPodResource($this->whenLoaded("ePod")),

            // timestamps
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ];
    }
}
