<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Customer extends Model
{
    use HasFactory, Filterable;

    public $filterFields = [
        'admin_id',

        'vertical_name',
        'insured_name',
        'insured_policy_no',
        'insured_contact_person_name',
        'rm_name',
        'rm_email',
        'under_writer_name',
        'under_writer_email',
        'vertical_head_name',
        'vertical_head_email',
    ];

    protected $fillable = [
        'admin_id',

        'cri_code',
        'vertical_name',
        'insured_name',
        'insured_policy_no',
        'insured_contact_person_name',
        'insured_contact_person_mobile_no',
        'rm_name',
        'rm_mobile_no',
        'rm_email',
        'under_writer_name',
        'under_writer_mobile_no',
        'under_writer_email',
        'vertical_head_name',
        'vertical_head_mobile_no',
        'vertical_head_email',
    ];

    // Automatically generate the cri_code
    protected static function boot(): void {
        parent::boot();

        // Before creating a customer, set the cri_code
        static::creating(function ($customer) {
            $customer->cri_code = self::generateCRICode();
        });
    }

    /**
     * Generate a new cri_code with the format ILCRI11111, ILCRI11112, ...
     */
    public static function generateCRICode(): string {
        // Get the last distributor by distributor_id
        $lastCustomer = self::orderBy('id', 'desc')->first();

        // Default starting number (ILCRI11111)
        $prefix = 'ILCRI';
        $startNumber = 11111;

        if (!$lastCustomer) {
            // No customer yet, return the first one
            return $prefix.$startNumber;
        }

        // Get the numeric part from the last cri_code and increment it
        $lastNumber = (int) substr($lastCustomer->cri_code, 5); // Remove the prefix
        $newNumber = $lastNumber + 1;

        // Return the new cri_code in the format SI1111, SI1112, etc.
        return $prefix.$newNumber;
    }

    public function admin(): BelongsTo {
        return $this->belongsTo(User::class, 'admin_id');
    }

    public function transporters(): HasMany {
        return $this->hasMany(Transporter::class, 'customer_id');
    }
}
