<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Transporter extends Model
{
    use HasFactory, Filterable;

    public $filterFields = [
        'created_by_id',
        'customer_id',

        'name',
        'email',
        'mobile_no_1',
        'mobile_no_2',
        'state',
    ];

    protected $fillable = [
        'created_by_id',
        'customer_id',

        'name',
        'email',
        'mobile_no_1',
        'mobile_no_2',
        'address',
        'state',
    ];


    // Automatically generate the transporter_code
    protected static function boot(): void {
        parent::boot();

        // Before creating a transporter, set the transporter_code
        static::creating(function ($transporter) {
            $transporter->transporter_code = self::generateTransporterCode();
        });
    }

    /**
     * Generate a new transporter_code with the format ILT11111, ILT11112, ...
     */
    public static function generateTransporterCode(): string {
        // Get the last transporter
        $lastTransporter = self::orderBy('id', 'desc')->first();

        // Default starting number (ILT11111)
        $prefix = 'ILT';
        $startNumber = 11111;

        if (!$lastTransporter) {
            // No transporter yet, return the first one
            return $prefix.$startNumber;
        }

        // Get the numeric part from the last transporter_code and increment it
        $lastNumber = (int) substr($lastTransporter->transporter_code, 3); // Remove the prefix
        $newNumber = $lastNumber + 1;

        // Return the new transporter_code in the format ILT11111, ILT11112, etc.
        return $prefix.$newNumber;
    }

    public function createdBy(): BelongsTo {
        return $this->belongsTo(User::class, 'created_by_id');
    }

    public function customer(): BelongsTo {
        return $this->belongsTo(Customer::class);
    }

    public function vehicles(): HasMany {
        return $this->hasMany(Vehicle::class, 'transporter_id');
    }

    public function drivers(): HasMany {
        return $this->hasMany(Driver::class, 'transporter_id');
    }

    public function trips(): HasMany {
        return $this->hasMany(Trip::class, 'transporter_id');
    }
}
