<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Auth\Passwords\CanResetPassword as CanResetPasswordTrait;
use Illuminate\Contracts\Auth\CanResetPassword as CanResetPasswordContract;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Model implements CanResetPasswordContract
{
    use HasFactory, Notifiable, HasApiTokens, Filterable, CanResetPasswordTrait;

    public $filterFields = [
        "created_by_id",

        "name",
        "email",
        "mobile_no",
        "role",
        "status"
    ];

    protected $fillable = [
        "created_by_id",

        'name',
        'email',
        'mobile_no',
        'password',
        'role',
        'status',
        'last_login_at'
    ];
    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    public function customers(): HasMany {
        return $this->hasMany(Customer::class, "admin_id");
    }

    public function transporters(): HasMany {
        return $this->hasMany(Transporter::class, 'created_by_id');
    }

    public function dispatcherTrips(): HasMany {
        return $this->hasMany(Trip::class, 'dispatcher_id');
    }

    public function receiverTrips(): HasMany {
        return $this->hasMany(Trip::class, 'receiver_id');
    }

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed',
        ];
    }
}
