<?php

namespace App\Services;

use GuzzleHttp\Exception\ClientException;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Facades\Log;

class APIClub
{
    const RC = "/rc_info";
    const DL = "/fetch_dl";
    const SEND_OTP = "/aadhaar_v2/send_otp";
    const SUBMIT_OTP = "/aadhaar_v2/submit_otp";

    static function sendRequest($endpoint, $data) {
        try {
            $client = new \GuzzleHttp\Client();
            $response = $client->request('POST', config("apiClub.base_url").$endpoint, [
                'body' => json_encode($data),  // Encode data properly to JSON format
                'headers' => [
                    'Referer' => 'docs.apiclub.in',
                    'accept' => 'application/json',
                    'content-type' => 'application/json',
                    'x-api-key' => config("apiClub.api_key"),
                ],
            ]);

            // Decode the response body into an associative array
            $responseBody = json_decode($response->getBody(), true);

            // Check if the API response is successful and is valid JSON
            if ($responseBody) {
                Log::info($responseBody);
                return $responseBody;
            }

            // Return null if the response body is empty or invalid
            return null;

        } catch (ClientException|GuzzleException $e) {
            Log::error($e);
            // Get the response body from the exception
            $response = $e->getResponse();
            return json_decode($response->getBody()->getContents(), true);

        } catch (\Exception $e) {
            // Handle any other exceptions
            return response()->json([
                'status' => 'error',
                'message' => $e->getMessage(),
            ], 500);
        }
    }
}
