<?php

use App\Enums\TripStatus;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    public function up(): void {
        Schema::create('trips', function (Blueprint $table) {
            $table->id();

            $table->foreignId('dispatcher_id')
                ->constrained("users")->cascadeOnDelete();
            $table->foreignId('receiver_id')
                ->constrained("users")->cascadeOnDelete();
            $table->foreignId('transporter_id')
                ->constrained("transporters")->cascadeOnDelete();
            $table->foreignId('vehicle_id')
                ->constrained("vehicles")->cascadeOnDelete();
            $table->foreignId('driver_id')
                ->constrained("drivers")->cascadeOnDelete();

            $table->boolean('is_chassis_no_verified')->default(false);
            $table->boolean('is_engine_no_verified')->default(false);
            $table->boolean('is_make_verified')->default(false);
            $table->boolean('is_model_verified')->default(false);
            $table->boolean('is_carrying_capacity_verified')->default(false);
            $table->boolean('is_vehicle_type_verified')->default(false);
            $table->boolean('is_aadhaar_verified')->default(false);
            $table->boolean('is_dl_verified')->default(false);
            $table->boolean('is_dob_verified')->default(false);
            $table->boolean('is_address_verified')->default(false);
            $table->boolean('is_mobile_no_verified')->default(false);
            $table->string('dob_remark')->nullable();
            $table->string('address_remark')->nullable();
            $table->string('trip_code', 10);
            $table->string('consignor_name');
            $table->string('consignee_name');
            $table->string('fast_tag_id', 30)->nullable();
            $table->string('dispatch_location');
            $table->string('dispatch_pincode', 10);
            $table->string('destination_location');
            $table->string('destination_pincode', 10);
            $table->decimal('latitude', 10, 8);
            $table->decimal('longitude', 11, 8);
            $table->text('goods_description')->nullable();
            $table->date('eta');
            $table->decimal('distance')->default(0);
            $table->boolean('is_e_pod_created')->default(false);

            $table->enum('status', array_column(TripStatus::cases(), "value"))
                ->default(TripStatus::PENDING->value);

            $table->timestamps();
        });
    }

    public function down(): void {
        Schema::dropIfExists('trips');
    }
};
