<?php

namespace Database\Seeders;

use App\Enums\TripStatus;
use App\Enums\UserRole;
use App\Models\Customer;
use App\Models\Driver;
use App\Models\EPod;
use App\Models\Transporter;
use App\Models\Trip;
use App\Models\User;
use App\Models\Vehicle;
use Illuminate\Database\Seeder;

// use Illuminate\Database\Console\Seeds\WithoutModelEvents;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void {
        $userRoles = array_column(UserRole::cases(), "value");

        $admin = User::factory()->create([
            "name" => UserRole::ADMIN->value,
            "email" => "admin@admin.com",
            "role" => UserRole::ADMIN->value
        ]);

        $insuredAdmin = User::factory()->create([
            "name" => UserRole::INSURED_ADMIN->value,
            "created_by_id" => $admin->id,
            "email" => "insured-admin@admin.com",
            "role" => UserRole::INSURED_ADMIN->value
        ]);

        $dispatcher = User::factory()->create([
            "name" => UserRole::DISPATCHER->value,
            "created_by_id" => $insuredAdmin->id,
            "email" => "dispatcher@admin.com",
            "role" => UserRole::DISPATCHER->value
        ]);

        $receiver = User::factory()->create([
            "name" => UserRole::RECEIVER->value,
            "created_by_id" => $insuredAdmin->id,
            "email" => "receiver@admin.com",
            "role" => UserRole::RECEIVER->value
        ]);

        $customer = Customer::factory()->create([
            "admin_id" => $admin->id,
        ]);

        $transporter = Transporter::factory()->create([
            "customer_id" => $customer->id,
            "created_by_id" => $insuredAdmin->id,
        ]);

        $vehicle = Vehicle::factory()->create([
            'transporter_id' => $transporter->id,
        ]);

        $driver = Driver::factory()->create([
            "transporter_id" => $transporter->id,
        ]);

        $trip = Trip::factory()->create([
            "transporter_id" => $transporter->id,
            "dispatcher_id" => $dispatcher->id,
            "vehicle_id" => $vehicle->id,
            "driver_id" => $driver->id,
            "receiver_id" => $receiver->id,
            "is_e_pod_created" => true,
            "status" => TripStatus::COMPLETED->value,
        ]);

        $ePod = EPod::factory()->create([
            "trip_id" => $trip->id,
            "receiver_id" => $receiver->id,
        ]);
    }
}
