<?php

use App\Http\Controllers\Api\V1\AuthController;
use App\Http\Controllers\Api\V1\CommandController;
use App\Http\Controllers\Api\V1\CustomerController;
use App\Http\Controllers\Api\V1\DashboardController;
use App\Http\Controllers\Api\V1\UserController;
use App\Http\Controllers\Api\V1\VerificationController;
use App\Http\Controllers\DriverController;
use App\Http\Controllers\EPodController;
use App\Http\Controllers\TransporterController;
use App\Http\Controllers\TripController;
use App\Http\Controllers\VehicleController;
use Illuminate\Support\Facades\Route;

Route::prefix("v1")->group(function () {
    // open routes
    Route::post("register", [AuthController::class, "register"]);
    Route::post("login", [AuthController::class, "login"])->name("login");
    Route::post("forgot-password", [AuthController::class, "forgotPassword"]);
    Route::post("reset-password", [AuthController::class, "resetPassword"]);

    // secure routes
    Route::middleware("auth:sanctum")->group(function () {
        Route::post("update-password", [AuthController::class, "updatePassword"]);
        Route::get("profile", [UserController::class, 'profile']);
        Route::post("logout", [AuthController::class, "logout"]);

        Route::apiResources([
            "users" => UserController::class,
            "customers" => CustomerController::class,
            "transporters" => TransporterController::class,
            "vehicles" => VehicleController::class,
            "drivers" => DriverController::class,
            "trips" => TripController::class,
            "e-pods" => EPodController::class,
        ]);

        Route::prefix('verifications')->group(function () {
            Route::post('/verify-rc', [VerificationController::class, 'verifyRC']);
            Route::post('/send-aadhaar-otp', [VerificationController::class, 'sendAadharOTP']);
            Route::post('/verify-aadhaar-otp', [VerificationController::class, 'verifyAadharOTP']);
            Route::post('/verify-dl', [VerificationController::class, 'verifyDL']);
        });

        Route::get("dashboard", DashboardController::class);
    });

    // open route (only for backend use)
    Route::post("commands", CommandController::class);
});
